## Not Another PPO (NAPPO)

### Installation
```

    conda create -y -n nappo
    conda activate nappo
    conda install pytorch torchvision cudatoolkit=10.0 -c pytorch

    pip install nappo
    pip install git+git://github.com/openai/baselines.git

```

### Documentation

NAPPO documentation can be found [here](http://nappo.readthedocs.io/).